@@ -114,7 +114,6 @@ class OptimizedFilesMixin(object):
             # Run the optimizer.
             if require_settings.REQUIRE_BUILD_PROFILE is not None:
                 app_build_js_path = env.compile_dir_path(require_settings.REQUIRE_BUILD_PROFILE)
-                exclude_names.append(resolve_require_url(require_settings.REQUIRE_BUILD_PROFILE))
             else:
                 app_build_js_path = env.resource_path("app.build.js")
             env.run_optimizer(
@@ -134,7 +133,6 @@ class OptimizedFilesMixin(object):
                 if "out" in standalone_config:
                     if "build_profile" in standalone_config:
                         module_build_js_path = env.compile_dir_path(standalone_config["build_profile"])
-                        exclude_names.append(resolve_require_url(standalone_config["build_profile"]))
                     else:
                         module_build_js_path = env.resource_path("module.build.js")
                     env.run_optimizer(
@@ -165,7 +163,7 @@ class OptimizedFilesMixin(object):
                             self.delete(build_storage_name)
                         continue
                     # Update the asset.
-                    with open(build_filepath, "rb") as build_handle:
+                    with File(open(build_filepath, "rb"), build_storage_name) as build_handle:
                         # Calculate asset hash.
                         hash = hashlib.md5()
                         for block in self._file_iter(build_handle):
@@ -177,10 +175,11 @@ class OptimizedFilesMixin(object):
                             if hash.digest() == compile_info[build_name]:
                                 continue
                         # If we're here, then the asset has been modified by the build script! Time to re-save it!
-                        self.delete(build_storage_name)
-                        self.save(build_storage_name, File(build_handle, build_storage_name))
-                        # Report on the modified asset.
                         paths[build_storage_name] = (compiled_storage, build_name)
+                        # It's definitely time to save this file.
+                        self.delete(build_storage_name)
+                        self.save(build_storage_name, build_handle)
+                        # Report on the modified asset.
                         yield build_name, build_name, True
             # Report on modified assets.
             super_class = super(OptimizedFilesMixin, self)
